@@ -2313,7 +2313,7 @@ class DataPrep:
         """
         try:
             logging.info(status_description)
-            url = "/v1/project/action"
+            url = "/v1/actions"
             payload = {
                 "_id": self.action_record_id,
                 "action": self.action_type,
