@@ -27,7 +27,8 @@ from .core.config import (
     IntrusionConfig,
     ProximityConfig,
     config_manager,
-    ConfigValidationError
+    ConfigValidationError,
+    PeopleTrackingConfig
 )
 from .usecases import (
     PeopleCountingUseCase,
@@ -94,12 +95,20 @@ from .usecases import (
     SmokerDetectionUseCase,
     RoadTrafficUseCase,
     RoadViewSegmentationUseCase,
-    FaceRecognitionUseCase,
+    # FaceRecognitionUseCase,
     DrowsyDriverUseCase,
     WaterBodyUseCase,
     LicensePlateMonitorUseCase,
     DwellUseCase,
     AgeGenderUseCase,
+    PeopleTrackingUseCase,
+
+    WildLifeMonitoringUseCase,
+    PCBDefectUseCase,
+    UndergroundPipelineDefectUseCase,
+
+    SusActivityUseCase,
+    NaturalDisasterUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -112,6 +121,9 @@ from .usecases import (
 
 )
 
+# Face recognition with embeddings (from face_reg module)
+from .face_reg.face_recognition import FaceRecognitionEmbeddingUseCase
+
 logger = logging.getLogger(__name__)
 
 
@@ -234,7 +246,8 @@ class PostProcessor:
         registry.register_use_case("general", "smoker_detection", SmokerDetectionUseCase)
         registry.register_use_case("automobile", "road_traffic_density", RoadTrafficUseCase)
         registry.register_use_case("automobile", "road_view_segmentation", RoadViewSegmentationUseCase)
-        registry.register_use_case("security", "face_recognition", FaceRecognitionUseCase)
+        # registry.register_use_case("security", "face_recognition", FaceRecognitionUseCase)
+        registry.register_use_case("security", "face_recognition", FaceRecognitionEmbeddingUseCase)
         registry.register_use_case("automobile", "drowsy_driver_detection", DrowsyDriverUseCase)
         registry.register_use_case("agriculture", "waterbody_segmentation", WaterBodyUseCase)
         registry.register_use_case("litter_detection", "litter_detection", LitterDetectionUseCase)
@@ -244,6 +257,12 @@ class PostProcessor:
         registry.register_use_case("license_plate_monitor", "license_plate_monitor", LicensePlateMonitorUseCase)
         registry.register_use_case("general", "dwell", DwellUseCase)
         registry.register_use_case("age_gender_detection", "age_gender_detection", AgeGenderUseCase)
+        registry.register_use_case("general", "people_tracking", PeopleTrackingUseCase)
+        registry.register_use_case("environmental", "wildlife_monitoring", WildLifeMonitoringUseCase)
+        registry.register_use_case("manufacturing", "pcb_defect_detection", PCBDefectUseCase)
+        registry.register_use_case("general", "underground_pipeline_defect", UndergroundPipelineDefectUseCase)
+        registry.register_use_case("security", "suspicious_activity_detection", SusActivityUseCase)
+        registry.register_use_case("environmental", "natural_disaster_detection", NaturalDisasterUseCase)
 
         #Put all IMAGE based usecases here
         registry.register_use_case("healthcare", "bloodcancer_img_detection", BloodCancerDetectionUseCase)
@@ -424,8 +443,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, RoadViewSegmentationUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
-            elif isinstance(use_case, FaceRecognitionUseCase):
-                result = use_case.process(data, parsed_config, context, stream_info)
+            # elif isinstance(use_case, FaceRecognitionUseCase):
+            #     result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, DrowsyDriverUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, WaterBodyUseCase):
@@ -444,6 +463,16 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config,context, stream_info)
             elif isinstance(use_case, AgeGenderUseCase):
                 result = use_case.process(data, parsed_config, input_bytes,context, stream_info)
+            # elif isinstance(use_case, PeopleTrackingUseCase):
+            #     result = use_case.process(data, parsed_config, input_bytes,context, stream_info)
+            elif isinstance(use_case, WildLifeMonitoringUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, PCBDefectUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, SusActivityUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, NaturalDisasterUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             
             #Put all IMAGE based usecases here
             elif isinstance(use_case, BloodCancerDetectionUseCase):
@@ -458,7 +487,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, CellMicroscopyUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
-
+            elif isinstance(use_case, FaceRecognitionEmbeddingUseCase):
+                result = await use_case.process(data, parsed_config, input_bytes, context, stream_info)
             else:
                 result = use_case.process(data, parsed_config, context, stream_info)
 
@@ -517,6 +547,8 @@ class PostProcessor:
                     category = "sales"
                 elif usecase in ["color_detection", "video_color_classification"]:
                     category = "visual_appearance"
+                elif usecase == "people_tracking":
+                    category = "general"
                 else:
                     category = "general"  # Default fallback
             
