@@ -66,7 +66,7 @@ from .leaf import LeafConfig, LeafUseCase
 from .smoker_detection import SmokerDetectionConfig, SmokerDetectionUseCase
 from .road_traffic_density import RoadTrafficConfig, RoadTrafficUseCase
 from .road_view_segmentation import RoadViewSegmentationConfig, RoadViewSegmentationUseCase
-from .face_recognition import FaceRecognitionConfig, FaceRecognitionUseCase
+# from .face_recognition import FaceRecognitionConfig, FaceRecognitionUseCase
 from .drowsy_driver_detection import DrowsyDriverUseCase, DrowsyDriverUseCase
 from .waterbody_segmentation import WaterBodyConfig, WaterBodyUseCase
 from .litter_monitoring import LitterDetectionConfig,LitterDetectionUseCase
@@ -79,6 +79,12 @@ from .gas_leak_detection import GasLeakDetectionConfig, GasLeakDetectionUseCase
 from .license_plate_monitoring import LicensePlateMonitorConfig,LicensePlateMonitorUseCase
 from .dwell_detection import DwellConfig,DwellUseCase
 from .age_gender_detection import AgeGenderConfig,AgeGenderUseCase
+from .people_tracking import PeopleTrackingConfig,PeopleTrackingUseCase
+from .wildlife_monitoring import WildLifeMonitoringConfig, WildLifeMonitoringUseCase
+from .pcb_defect_detection import PCBDefectConfig, PCBDefectUseCase
+from .underground_pipeline_defect_detection import UndergroundPipelineDefectConfig,UndergroundPipelineDefectUseCase
+from .suspicious_activity_detection import SusActivityConfig, SusActivityUseCase
+from .natural_disaster import NaturalDisasterConfig, NaturalDisasterUseCase
 
 #Put all IMAGE based usecases here
 from .blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
@@ -88,8 +94,11 @@ from .cardiomegaly_classification import CardiomegalyConfig, CardiomegalyUseCase
 from .Histopathological_Cancer_Detection_img import HistopathologicalCancerDetectionConfig,HistopathologicalCancerDetectionUseCase
 from .cell_microscopy_segmentation import CellMicroscopyConfig, CellMicroscopyUseCase
 
+from ..face_reg.face_recognition import FaceRecognitionEmbeddingUseCase, FaceRecognitionEmbeddingConfig
 
 __all__ = [
+    'FaceRecognitionEmbeddingUseCase',
+    'FaceRecognitionEmbeddingConfig',
     'PeopleCountingUseCase',
     'IntrusionUseCase',
     'ProximityUseCase',
@@ -144,7 +153,7 @@ __all__ = [
     'SmokerDetectionUseCase',
     'RoadTrafficUseCase',
     'RoadViewSegmentationUseCase',
-    'FaceRecognitionUseCase',
+    # 'FaceRecognitionUseCase',
     'DrowsyDriverUseCase',
     'WaterBodyUseCase',
     'LitterDetectionUseCase',
@@ -155,6 +164,12 @@ __all__ = [
     'LicensePlateMonitorUseCase',
     'DwellUseCase',
     'AgeGenderUseCase',
+    'PeopleTrackingUseCase',
+    'WildLifeMonitoringUseCase',
+    'PCBDefectUseCase',
+    'UndergroundPipelineDefectUseCase',
+    'SusActivityUseCase',
+    'NaturalDisasterUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
@@ -219,19 +234,24 @@ __all__ = [
     'SmokerDetectionConfig',
     'RoadTrafficConfig',
     'RoadViewSegmentationConfig',
-    'FaceRecognitionConfig',
+    # 'FaceRecognitionConfig',
     'DrowsyDriverUseCase',
     'WaterBodyConfig',
     'LitterDetectionConfig',
     'AbandonedObjectConfig',
     'DwellConfig',
     'AgeGenderConfig',
+    'PeopleTrackingConfig',
+    'UndergroundPipelineDefectConfig',
 
     'LeakDetectionConfig',
     'HumanActivityConfig',
     'GasLeakDetectionConfig',
     'LicensePlateMonitorConfig',
-
+    'WildLifeMonitoringConfig',
+    'PCBDefectConfig',
+    'SusActivityConfig',
+    'NaturalDisasterConfig',
 
     #Put all IMAGE based usecase CONFIGS here
     'BloodCancerDetectionConfig',
