@@ -537,7 +537,7 @@ class AgeGenderUseCase(BaseProcessor):
         result_list = [(pair,count) for pair, count in pair_counts.items()]
         human_text_lines.append("")
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
-        human_text_lines.append(f"\t- Total Detected: {len(self.all_track_data)}")
+        human_text_lines.append(f"\t- Total Detected: {len(age_gender_data['Mean Age'])}")
         for pair, count in result_list:
             human_text_lines.append(f"\t\t{pair}:{count}")
 
